@@ -1,5 +1,5 @@
 """
-Copyright  2016-2019 Maël Azimi <m.a@moul.re>
+Copyright  2016-2020 Maël Azimi <m.a@moul.re>
 
 Silkaj is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
@@ -15,11 +15,18 @@ You should have received a copy of the GNU Affero General Public License
 along with Silkaj. If not, see <https://www.gnu.org/licenses/>.
 """
 
-SILKAJ_VERSION = "0.7.6"
+SILKAJ_VERSION = "0.8.0"
 G1_SYMBOL = "Ğ1"
 GTEST_SYMBOL = "ĞTest"
 G1_DEFAULT_ENDPOINT = "g1.duniter.org", "443"
 G1_TEST_DEFAULT_ENDPOINT = "g1-test.duniter.org", "443"
 CONNECTION_TIMEOUT = 10
-ASYNC_SLEEP = 0.1
+ASYNC_SLEEP = 0.15
 SOURCES_PER_TX = 40
+SUCCESS_EXIT_STATUS = 0
+FAILURE_EXIT_STATUS = 1
+BMA_MAX_BLOCKS_CHUNK_SIZE = 5000
+PUBKEY_PATTERN = "[1-9A-HJ-NP-Za-km-z]{43,44}"
+MINIMAL_TX_AMOUNT = 0.01
+CENT_MULT_TO_UNIT = 100
+SHORT_PUBKEY_SIZE = 8
